==> climdex.pcic_1.0-3.tar.gz: climdex.pcic/man/climdex.r99ptot.Rd <==
\name{climdex.r99ptot}
\alias{climdex.r99ptot}
\title{Total Daily Precipitation Exceeding 99\%ile Threshold}
\usage{
  climdex.r99ptot(ci)
}
\arguments{
  \item{ci}{Object of type climdexInput.}
}
\value{
  A vector containing an annual timeseries of precipitation
  exceeding the threshold.
}
\description{
  This function computes the climdex index R99pTOT.
}
\details{
  This function takes a climdexInput object as input and
  computes the climdex index R99pTOT: the annual sum of
  precipitation in days where daily precipitation exceeds
  the 99th percentile of daily precipitation in the base
  period.
}
\examples{
## Create a climdexInput object from some data already loaded in and
## ready to go.

## Parse the dates into PCICt.
tmax.dates <- as.PCICt(do.call(paste, ec.1018935.tmax[,c("year",
"jday")]), format="\%Y \%j", cal="gregorian")
tmin.dates <- as.PCICt(do.call(paste, ec.1018935.tmin[,c("year",
"jday")]), format="\%Y \%j", cal="gregorian")
prec.dates <- as.PCICt(do.call(paste, ec.1018935.prec[,c("year",
"jday")]), format="\%Y \%j", cal="gregorian")

## Load the data in.
ci <- climdexInput.raw(ec.1018935.tmax$MAX_TEMP,
ec.1018935.tmin$MIN_TEMP, ec.1018935.prec$ONE_DAY_PRECIPITATION,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create an annual timeseries of the R99pTOT index.
r99ptot <- climdex.r99ptot(ci)
}
\references{
  \url{http://cccma.seos.uvic.ca/ETCCDMI/list_27_indices.shtml}
}
\seealso{
  \code{\link{climdexInput.raw}},
  \code{\link{climdexInput.csv}}.
}
\keyword{climate}
\keyword{ts}

==> climdex.pcic_1.1-1.tar.gz: climdex.pcic/man/climdex.r99ptot.Rd <==
\name{climdex.r99ptot}
\alias{climdex.r99ptot}
\title{Total Daily Precipitation Exceeding 99\%ile Threshold}
\usage{
climdex.r99ptot(ci)
}
\arguments{
  \item{ci}{Object of type climdexInput.}
}
\value{
A vector containing an annual timeseries of precipitation
exceeding the threshold.
}
\description{
This function computes the climdex index R99pTOT.
}
\details{
This function takes a climdexInput object as input and
computes the climdex index R99pTOT: the annual sum of
precipitation in days where daily precipitation exceeds the
99th percentile of daily precipitation in the base period.
}
\examples{
library(PCICt)

## Create a climdexInput object from some data already loaded in and
## ready to go.

## Parse the dates into PCICt.
tmax.dates <- as.PCICt(do.call(paste, ec.1018935.tmax[,c("year",
"jday")]), format="\%Y \%j", cal="gregorian")
tmin.dates <- as.PCICt(do.call(paste, ec.1018935.tmin[,c("year",
"jday")]), format="\%Y \%j", cal="gregorian")
prec.dates <- as.PCICt(do.call(paste, ec.1018935.prec[,c("year",
"jday")]), format="\%Y \%j", cal="gregorian")

## Load the data in.
ci <- climdexInput.raw(ec.1018935.tmax$MAX_TEMP,
ec.1018935.tmin$MIN_TEMP, ec.1018935.prec$ONE_DAY_PRECIPITATION,
tmax.dates, tmin.dates, prec.dates, base.range=c(1971, 2000))

## Create an annual timeseries of the R99pTOT index.
r99ptot <- climdex.r99ptot(ci)
}
\references{
\url{http://etccdi.pacificclimate.org/list_27_indices.shtml}
}
\seealso{
\code{\link{climdexInput.raw}},
\code{\link{climdexInput.csv}}.
}
\keyword{climate}
\keyword{ts}
